==> mightymite-0.3.3.tgz: package/lib/templates.js <==

/**
 * Dependencies
 */
var _       = require('lodash');
var fm      = require('front-matter');
var fs      = require('vinyl-fs');
var map     = require('map-stream');
var nfs     = require('fs');
var path    = require('path');
var q       = require('q');
var swig    = require('swig');

/**
 * Local dependencies
 */
var mm = require('./mightymite');
var util = require('./utilities');
var dot = util.dot;

/**
 * Initialization
 */
module.exports.init = function () {

    var def = q.defer();

    mm.helpers = {};
    mm.layouts = {};
    mm.partials = {};

    q.all([
        registerPartials(),
        registerLayouts(),
    ]).done(function() {
        //console.log(mm.partials);
        def.resolve();
    });

    return def.promise;
};

/**
 * Register partials
 * TODO: get front-matter, compile templates?
 */
var registerPartials = function() {

    var def = q.defer();

    var src = path.resolve(mm.config.partialsDir, '**/*.{' + mm.config.templateTypes + '}');

    fs.src(src)
        .pipe(map(function(file, callback) {

            var dotPath = util.getDotPath(file, mm.config.partialsDir);

            util.set(mm.partials, dotPath, {
                path: file.path,
                contents: String(file.contents)
            });

            callback();
        }))
        .on('end', function() {
            def.resolve();
        });

    return def.promise;
};

/**
 * Register layouts
 * TODO: enable nested layouts
 */
var registerLayouts = function() {

    var def = q.defer();

    var src = path.resolve(mm.config.layoutsDir, '**/*.{' + mm.config.templateTypes + '}');

    fs.src(src)
        .pipe(map(function(file, callback) {

            var dotPath = util.getDotPath(file, mm.config.layoutsDir);

            util.set(mm.layouts, dotPath, {
                path: file.path,
                contents: String(file.contents)
            });

            callback();
        }))
        .on('end', function() {
            def.resolve();
        });

    return def.promise;
};

/**
 * Compile a template
 *
 * @param  {object} template {path: './path/to/file', contents: String(file.contents)}
 * @param  {object} locals   Local variables to pass to template on compilation.
 * @return {function}        Swig template function
 */
var compile = function(template, locals)  {

    var contents = fm(template.contents);

    var locals = _.merge(contents.attributes, locals);

    var body = contents.body;

    // If a layout is set, extend it
    if (locals.layout) {

        body = '{% block body %}' + body + '{% endblock %}';
        var layout = util.get(mm.layouts, locals.layout);

        if (layout) {
            body = '{% extends "' + layout.path + '" %}' + body;
        }
    }

    // Compile template
    var tpl = swig.compile(body, {
        filename: template.path,
        locals: _.merge(locals, templateFunctions)
    });

    // Return rendered template
    return tpl(locals);
};

/**
 * Default helper functions, available to templates
 */
var templateFunctions = {

    /**
     * Insert a partial
     *
     * {{ partial('path/to/partial') }}
     */
    partial: function(name, obj) {
        return compile(util.get(mm.partials, name), obj);
    },

    /**
     * Retreive collections from the data store
     *
     * {{ data('path/to/collection') }}
     */
    data: function(key) {
        return util.get(mm.data, key);
    }

};

module.exports.compile = compile;

==> mightymite-0.3.4.tgz: package/lib/templates.js <==

/**
 * Dependencies
 */
var _       = require('lodash');
var fm      = require('front-matter');
var fs      = require('vinyl-fs');
var map     = require('map-stream');
var nfs     = require('fs');
var path    = require('path');
var q       = require('q');
var swig    = require('swig');

/**
 * Local dependencies
 */
var mm = require('./mightymite');
var util = require('./utilities');
var dot = util.dot;

/**
 * Initialization
 */
module.exports.init = function () {

    var def = q.defer();

    mm.helpers = {};
    mm.layouts = {};
    mm.partials = {};

    q.all([
        registerPartials(),
        registerLayouts(),
        registerHelpers(),
    ]).done(function() {
        //console.log(mm.helpers);
        def.resolve();
    });

    return def.promise;
};

/**
 * Register partials
 */
var registerPartials = function() {

    var def = q.defer();

    var src = path.resolve(mm.config.partialsDir, '**/*.{' + mm.config.templateTypes + '}');

    fs.src(src)
        .pipe(map(function(file, callback) {

            var dotPath = util.getDotPath(file, mm.config.partialsDir);

            util.set(mm.partials, dotPath, {
                path: file.path,
                contents: String(file.contents)
            });

            callback();
        }))
        .on('end', function() {
            def.resolve();
        });

    return def.promise;
};

/**
 * Register layouts
 */
var registerLayouts = function() {

    var def = q.defer();

    var src = path.resolve(mm.config.layoutsDir, '**/*.{' + mm.config.templateTypes + '}');

    fs.src(src)
        .pipe(map(function(file, callback) {

            var dotPath = util.getDotPath(file, mm.config.layoutsDir);

            util.set(mm.layouts, dotPath, {
                path: file.path,
                contents: String(file.contents)
            });

            callback();
        }))
        .on('end', function() {
            def.resolve();
        });

    return def.promise;
};

/**
 * Register helpers
 */
var registerHelpers = function() {

    var def = q.defer();

    var src = path.resolve(mm.config.helpersDir, '**/*.js');

    // Register default helpers
    _.each(helpers, function(helper, key) {
        util.set(mm.helpers, key, helper);
    });

    fs.src(src)
        .pipe(map(function(file, callback) {

            var dotPath = util.getDotPath(file, mm.config.helpersDir);

            util.set(mm.helpers, dotPath, require(file.path));

            callback();
        }))
        .on('end', function() {
            def.resolve();
        });

    return def.promise;
};

var registerHelper = function(name) {

};

/**
 * Compile a template
 *
 * @param  {object} template {path: './path/to/file', contents: String(file.contents)}
 * @param  {object} locals   Local variables to pass to template on compilation.
 * @return {function}        Swig template function
 */
var compile = function(template, locals)  {

    var contents = fm(template.contents);

    var locals = _.merge(contents.attributes, locals);

    var body = contents.body;

    // If a layout is set, extend it
    if (locals.layout) {

        body = '{% block body %}' + body + '{% endblock %}';
        var layout = util.get(mm.layouts, locals.layout);

        if (layout) {
            body = '{% extends "' + layout.path + '" %}' + body;
        }
    }

    // Compile template
    var tpl = swig.compile(body, {
        filename: template.path,
        locals: _.merge(locals, {
            helpers: mm.helpers
        })
    });

    // Return rendered template
    return tpl(locals);
};

/**
 * Default helper functions, available to templates
 */
var helpers = {

    /**
     * Insert a partial
     *
     * {{ partial('path/to/partial') }}
     */
    partial: function(name, obj) {
        return compile(util.get(mm.partials, name), obj);
    },

    /**
     * Retreive collections from the data store
     *
     * {{ data('path/to/collection') }}
     */
    data: function(path) {
        return util.get(mm.data, path);
    },

    /**
     * Get a relative path between pages
     *
     * Will always return with a trailing slash
     *
     * {{ path() }}         Returns path to root
     * {{ path('about') }}  Path to about page
     */
    path: function (pathStr) {
        return path.normalize(path.join(mm.config.root, pathStr + '/'));
    },

    /**
     * Make an HTML link tag
     */
    link: function(pathStr, title) {
        return '<a href="' + this.path(pathStr) + '">' + title + '</a>';
    }

};

module.exports.compile = compile;
